# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ExternalFiatAccountStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status of the account. A `pending` status indicates that the linking is in-progress; `complete` indicates the account was linked successfully; `failed` indicates it failed.
    """
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")
    
    @schemas.classproperty
    def COMPLETE(cls):
        return cls("complete")
    
    @schemas.classproperty
    def FAILED(cls):
        return cls("failed")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BillingDetails(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "country",
            "city",
            "postalCode",
            "name",
            "line1",
        }
        
        class properties:
            
            
            class name(
                schemas.StrSchema
            ):
                pass
            
            
            class city(
                schemas.StrSchema
            ):
                pass
            
            
            class country(
                schemas.StrSchema
            ):
                pass
            
            
            class line1(
                schemas.StrSchema
            ):
                pass
            
            
            class postalCode(
                schemas.StrSchema
            ):
                pass
            
            
            class line2(
                schemas.StrSchema
            ):
                pass
            
            
            class district(
                schemas.StrSchema
            ):
                pass
            __annotations__ = {
                "name": name,
                "city": city,
                "country": country,
                "line1": line1,
                "postalCode": postalCode,
                "line2": line2,
                "district": district,
            }
    
    country: MetaOapg.properties.country
    city: MetaOapg.properties.city
    postalCode: MetaOapg.properties.postalCode
    name: MetaOapg.properties.name
    line1: MetaOapg.properties.line1
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["city"]) -> MetaOapg.properties.city: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["country"]) -> MetaOapg.properties.country: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["line1"]) -> MetaOapg.properties.line1: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["postalCode"]) -> MetaOapg.properties.postalCode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["line2"]) -> MetaOapg.properties.line2: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["district"]) -> MetaOapg.properties.district: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "city", "country", "line1", "postalCode", "line2", "district", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["city"]) -> MetaOapg.properties.city: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["country"]) -> MetaOapg.properties.country: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["line1"]) -> MetaOapg.properties.line1: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["postalCode"]) -> MetaOapg.properties.postalCode: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["line2"]) -> typing.Union[MetaOapg.properties.line2, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["district"]) -> typing.Union[MetaOapg.properties.district, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "city", "country", "line1", "postalCode", "line2", "district", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        country: typing.Union[MetaOapg.properties.country, str, ],
        city: typing.Union[MetaOapg.properties.city, str, ],
        postalCode: typing.Union[MetaOapg.properties.postalCode, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        line1: typing.Union[MetaOapg.properties.line1, str, ],
        line2: typing.Union[MetaOapg.properties.line2, str, schemas.Unset] = schemas.unset,
        district: typing.Union[MetaOapg.properties.district, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BillingDetails':
        return super().__new__(
            cls,
            *_args,
            country=country,
            city=city,
            postalCode=postalCode,
            name=name,
            line1=line1,
            line2=line2,
            district=district,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Chain(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A blockchain that a given currency is available on.
    """
    
    @schemas.classproperty
    def ALGO(cls):
        return cls("ALGO")
    
    @schemas.classproperty
    def ARB(cls):
        return cls("ARB")
    
    @schemas.classproperty
    def AVAX(cls):
        return cls("AVAX")
    
    @schemas.classproperty
    def BASE(cls):
        return cls("BASE")
    
    @schemas.classproperty
    def BTC(cls):
        return cls("BTC")
    
    @schemas.classproperty
    def ETH(cls):
        return cls("ETH")
    
    @schemas.classproperty
    def FLOW(cls):
        return cls("FLOW")
    
    @schemas.classproperty
    def HBAR(cls):
        return cls("HBAR")
    
    @schemas.classproperty
    def NEAR(cls):
        return cls("NEAR")
    
    @schemas.classproperty
    def NOBLE(cls):
        return cls("NOBLE")
    
    @schemas.classproperty
    def OP(cls):
        return cls("OP")
    
    @schemas.classproperty
    def PAH(cls):
        return cls("PAH")
    
    @schemas.classproperty
    def POLY(cls):
        return cls("POLY")
    
    @schemas.classproperty
    def SOL(cls):
        return cls("SOL")
    
    @schemas.classproperty
    def TRX(cls):
        return cls("TRX")
    
    @schemas.classproperty
    def XLM(cls):
        return cls("XLM")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_payment_intents.post import CreatePaymentIntent
from circle.paths.v1_payment_intents_id_expire.post import ExpirePaymentIntent
from circle.paths.v1_payment_intents_id.get import GetPaymentIntent
from circle.paths.v1_payment_intents.get import ListPaymentIntents
from circle.paths.v1_payment_intents_id_refund.post import RefundPaymentIntent


class CryptoPaymentIntentsApi(
    CreatePaymentIntent,
    ExpirePaymentIntent,
    GetPaymentIntent,
    ListPaymentIntents,
    RefundPaymentIntent,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_checkout_sessions.post import CreateCheckoutSession
from circle.paths.v1_checkout_sessions_id_extend.post import ExtendCheckoutSession
from circle.paths.v1_checkout_sessions_id.get import GetCheckoutSession
from circle.paths.v1_checkout_sessions.get import ListCheckoutSessions


class CheckoutSessionsApi(
    CreateCheckoutSession,
    ExtendCheckoutSession,
    GetCheckoutSession,
    ListCheckoutSessions,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class FiatPayment(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Status information of the related payment. This property is only present on refund or cancel items.
    """


    class MetaOapg:
        required = {
            "amount",
            "merchantId",
            "id",
            "source",
            "type",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("payment")
            merchantId = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def source() -> typing.Type['SourceResponse']:
                return SourceResponse
        
            @staticmethod
            def status() -> typing.Type['PaymentStatus']:
                return PaymentStatus
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
        
            @staticmethod
            def fromAmount() -> typing.Type['FiatMoney']:
                return FiatMoney
            
            
            class description(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PAYMENT(cls):
                    return cls("Payment")
            captured = schemas.BoolSchema
        
            @staticmethod
            def captureAmount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            captureDate = schemas.StrSchema
        
            @staticmethod
            def requiredAction() -> typing.Type['RequiredAction']:
                return RequiredAction
        
            @staticmethod
            def cancel() -> typing.Type['PaymentInfoCancel']:
                return PaymentInfoCancel
            
            
            class refunds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentInfoPaymentAndRefund']:
                        return PaymentInfoPaymentAndRefund
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentInfoPaymentAndRefund'], typing.List['PaymentInfoPaymentAndRefund']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'refunds':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentInfoPaymentAndRefund':
                    return super().__getitem__(i)
        
            @staticmethod
            def fees() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            channel = schemas.UUIDSchema
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "type": type,
                "merchantId": merchantId,
                "amount": amount,
                "source": source,
                "status": status,
                "merchantWalletId": merchantWalletId,
                "fromAmount": fromAmount,
                "description": description,
                "captured": captured,
                "captureAmount": captureAmount,
                "captureDate": captureDate,
                "requiredAction": requiredAction,
                "cancel": cancel,
                "refunds": refunds,
                "fees": fees,
                "channel": channel,
                "createDate": createDate,
                "updateDate": updateDate,
            }
    
    amount: 'FiatMoneyUsd'
    merchantId: MetaOapg.properties.merchantId
    id: MetaOapg.properties.id
    source: 'SourceResponse'
    type: MetaOapg.properties.type
    status: 'PaymentStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["source"]) -> 'SourceResponse': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'PaymentStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fromAmount"]) -> 'FiatMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["captured"]) -> MetaOapg.properties.captured: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["captureAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["captureDate"]) -> MetaOapg.properties.captureDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["requiredAction"]) -> 'RequiredAction': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cancel"]) -> 'PaymentInfoCancel': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refunds"]) -> MetaOapg.properties.refunds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["channel"]) -> MetaOapg.properties.channel: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "source", "status", "merchantWalletId", "fromAmount", "description", "captured", "captureAmount", "captureDate", "requiredAction", "cancel", "refunds", "fees", "channel", "createDate", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantId"]) -> MetaOapg.properties.merchantId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["source"]) -> 'SourceResponse': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'PaymentStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fromAmount"]) -> typing.Union['FiatMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> typing.Union[MetaOapg.properties.description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["captured"]) -> typing.Union[MetaOapg.properties.captured, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["captureAmount"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["captureDate"]) -> typing.Union[MetaOapg.properties.captureDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["requiredAction"]) -> typing.Union['RequiredAction', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cancel"]) -> typing.Union['PaymentInfoCancel', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refunds"]) -> typing.Union[MetaOapg.properties.refunds, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["channel"]) -> typing.Union[MetaOapg.properties.channel, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "type", "merchantId", "amount", "source", "status", "merchantWalletId", "fromAmount", "description", "captured", "captureAmount", "captureDate", "requiredAction", "cancel", "refunds", "fees", "channel", "createDate", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'FiatMoneyUsd',
        merchantId: typing.Union[MetaOapg.properties.merchantId, str, uuid.UUID, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        source: 'SourceResponse',
        type: typing.Union[MetaOapg.properties.type, str, ],
        status: 'PaymentStatus',
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        fromAmount: typing.Union['FiatMoney', schemas.Unset] = schemas.unset,
        description: typing.Union[MetaOapg.properties.description, str, schemas.Unset] = schemas.unset,
        captured: typing.Union[MetaOapg.properties.captured, bool, schemas.Unset] = schemas.unset,
        captureAmount: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        captureDate: typing.Union[MetaOapg.properties.captureDate, str, schemas.Unset] = schemas.unset,
        requiredAction: typing.Union['RequiredAction', schemas.Unset] = schemas.unset,
        cancel: typing.Union['PaymentInfoCancel', schemas.Unset] = schemas.unset,
        refunds: typing.Union[MetaOapg.properties.refunds, list, tuple, schemas.Unset] = schemas.unset,
        fees: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        channel: typing.Union[MetaOapg.properties.channel, str, uuid.UUID, schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'FiatPayment':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            merchantId=merchantId,
            id=id,
            source=source,
            type=type,
            status=status,
            merchantWalletId=merchantWalletId,
            fromAmount=fromAmount,
            description=description,
            captured=captured,
            captureAmount=captureAmount,
            captureDate=captureDate,
            requiredAction=requiredAction,
            cancel=cancel,
            refunds=refunds,
            fees=fees,
            channel=channel,
            createDate=createDate,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money import FiatMoney
from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_info_cancel import PaymentInfoCancel
from circle.model.payment_info_payment_and_refund import PaymentInfoPaymentAndRefund
from circle.model.payment_status import PaymentStatus
from circle.model.required_action import RequiredAction
from circle.model.source_response import SourceResponse



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Balances(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Available and unsettled balances of the merchant.
    """


    class MetaOapg:
        required = {
            "unsettled",
            "available",
        }
        
        class properties:
            
            
            class available(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Money']:
                        return Money
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Money'], typing.List['Money']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'available':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Money':
                    return super().__getitem__(i)
            
            
            class unsettled(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Money']:
                        return Money
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Money'], typing.List['Money']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'unsettled':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Money':
                    return super().__getitem__(i)
            __annotations__ = {
                "available": available,
                "unsettled": unsettled,
            }
    
    unsettled: MetaOapg.properties.unsettled
    available: MetaOapg.properties.available
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["available"]) -> MetaOapg.properties.available: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["unsettled"]) -> MetaOapg.properties.unsettled: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["available", "unsettled", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["available"]) -> MetaOapg.properties.available: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["unsettled"]) -> MetaOapg.properties.unsettled: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["available", "unsettled", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        unsettled: typing.Union[MetaOapg.properties.unsettled, list, tuple, ],
        available: typing.Union[MetaOapg.properties.available, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Balances':
        return super().__new__(
            cls,
            *_args,
            unsettled=unsettled,
            available=available,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.money import Money



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class SimpleCard(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expMonth",
            "updateDate",
            "billingDetails",
            "expYear",
            "fingerprint",
            "id",
            "verification",
            "createDate",
            "network",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def status() -> typing.Type['ExternalFiatAccountStatus']:
                return ExternalFiatAccountStatus
        
            @staticmethod
            def billingDetails() -> typing.Type['SimpleBillingDetails']:
                return SimpleBillingDetails
            expMonth = schemas.IntSchema
            expYear = schemas.IntSchema
            
            
            class network(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def VISA(cls):
                    return cls("VISA")
                
                @schemas.classproperty
                def MASTERCARD(cls):
                    return cls("MASTERCARD")
                
                @schemas.classproperty
                def AMEX(cls):
                    return cls("AMEX")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("UNKNOWN")
            fingerprint = schemas.StrSchema
        
            @staticmethod
            def verification() -> typing.Type['CardVerificationResponse']:
                return CardVerificationResponse
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            bin = schemas.StrSchema
            issuerCountry = schemas.StrSchema
            
            
            class fundingType(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def CREDIT(cls):
                    return cls("credit")
                
                @schemas.classproperty
                def DEBIT(cls):
                    return cls("debit")
                
                @schemas.classproperty
                def PREPAID(cls):
                    return cls("prepaid")
                
                @schemas.classproperty
                def UNKNOWN(cls):
                    return cls("unknown")
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            __annotations__ = {
                "id": id,
                "status": status,
                "billingDetails": billingDetails,
                "expMonth": expMonth,
                "expYear": expYear,
                "network": network,
                "fingerprint": fingerprint,
                "verification": verification,
                "createDate": createDate,
                "updateDate": updateDate,
                "bin": bin,
                "issuerCountry": issuerCountry,
                "fundingType": fundingType,
                "riskEvaluation": riskEvaluation,
            }
    
    expMonth: MetaOapg.properties.expMonth
    updateDate: MetaOapg.properties.updateDate
    billingDetails: 'SimpleBillingDetails'
    expYear: MetaOapg.properties.expYear
    fingerprint: MetaOapg.properties.fingerprint
    id: MetaOapg.properties.id
    verification: 'CardVerificationResponse'
    createDate: MetaOapg.properties.createDate
    network: MetaOapg.properties.network
    status: 'ExternalFiatAccountStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'SimpleBillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> MetaOapg.properties.expMonth: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> MetaOapg.properties.expYear: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["verification"]) -> 'CardVerificationResponse': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bin"]) -> MetaOapg.properties.bin: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["issuerCountry"]) -> MetaOapg.properties.issuerCountry: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fundingType"]) -> MetaOapg.properties.fundingType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "status", "billingDetails", "expMonth", "expYear", "network", "fingerprint", "verification", "createDate", "updateDate", "bin", "issuerCountry", "fundingType", "riskEvaluation", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'ExternalFiatAccountStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'SimpleBillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> MetaOapg.properties.expMonth: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> MetaOapg.properties.expYear: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["network"]) -> MetaOapg.properties.network: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fingerprint"]) -> MetaOapg.properties.fingerprint: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["verification"]) -> 'CardVerificationResponse': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bin"]) -> typing.Union[MetaOapg.properties.bin, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["issuerCountry"]) -> typing.Union[MetaOapg.properties.issuerCountry, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fundingType"]) -> typing.Union[MetaOapg.properties.fundingType, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "status", "billingDetails", "expMonth", "expYear", "network", "fingerprint", "verification", "createDate", "updateDate", "bin", "issuerCountry", "fundingType", "riskEvaluation", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expMonth: typing.Union[MetaOapg.properties.expMonth, decimal.Decimal, int, ],
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, ],
        billingDetails: 'SimpleBillingDetails',
        expYear: typing.Union[MetaOapg.properties.expYear, decimal.Decimal, int, ],
        fingerprint: typing.Union[MetaOapg.properties.fingerprint, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        verification: 'CardVerificationResponse',
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        network: typing.Union[MetaOapg.properties.network, str, ],
        status: 'ExternalFiatAccountStatus',
        bin: typing.Union[MetaOapg.properties.bin, str, schemas.Unset] = schemas.unset,
        issuerCountry: typing.Union[MetaOapg.properties.issuerCountry, str, schemas.Unset] = schemas.unset,
        fundingType: typing.Union[MetaOapg.properties.fundingType, str, schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SimpleCard':
        return super().__new__(
            cls,
            *_args,
            expMonth=expMonth,
            updateDate=updateDate,
            billingDetails=billingDetails,
            expYear=expYear,
            fingerprint=fingerprint,
            id=id,
            verification=verification,
            createDate=createDate,
            network=network,
            status=status,
            bin=bin,
            issuerCountry=issuerCountry,
            fundingType=fundingType,
            riskEvaluation=riskEvaluation,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.card_verification_response import CardVerificationResponse
from circle.model.external_fiat_account_status import ExternalFiatAccountStatus
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.simple_billing_details import SimpleBillingDetails



import circle
from circle.apis.tags.management_api import ManagementApi

import unittest


class TestPing(unittest.TestCase):

    def setUp(self):
        circle.base_url = circle.Environment.SANDBOX_BASE_URL
        self.api = ManagementApi()

    def test_ping(self):
        with self.assertRaises(circle.ApiException):
            # Should error with ApiException because no API key provided
            self.api.get_account_config()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PayoutErrorCode(
    schemas.EnumBase,
    schemas.StrBase,
    schemas.NoneBase,
    schemas.Schema,
    schemas.NoneStrMixin
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Indicates the failure reason of a payout. Only present for payouts in failed state. Possible values are [`insufficient_funds`, `transaction_denied`, `transaction_failed`, `transaction_returned`, `bank_transaction_error`, `fiat_account_limit_exceeded`, `invalid_bank_account_number`, `invalid_ach_rtn`, `invalid_wire_rtn`, `vendor_inactive`]'
    """


    class MetaOapg:
        enum_value_to_name = {
            "insufficient_funds": "INSUFFICIENT_FUNDS",
            "transaction_denied": "TRANSACTION_DENIED",
            "transaction_failed": "TRANSACTION_FAILED",
            "transaction_returned": "TRANSACTION_RETURNED",
            "bank_transaction_error": "BANK_TRANSACTION_ERROR",
            "fiat_account_limit_exceeded": "FIAT_ACCOUNT_LIMIT_EXCEEDED",
            "invalid_bank_account_number": "INVALID_BANK_ACCOUNT_NUMBER",
            "invalid_ach_rtn": "INVALID_ACH_RTN",
            "invalid_wire_rtn": "INVALID_WIRE_RTN",
            "vendor_inactive": "VENDOR_INACTIVE",
        }
    
    @schemas.classproperty
    def INSUFFICIENT_FUNDS(cls):
        return cls("insufficient_funds")
    
    @schemas.classproperty
    def TRANSACTION_DENIED(cls):
        return cls("transaction_denied")
    
    @schemas.classproperty
    def TRANSACTION_FAILED(cls):
        return cls("transaction_failed")
    
    @schemas.classproperty
    def TRANSACTION_RETURNED(cls):
        return cls("transaction_returned")
    
    @schemas.classproperty
    def BANK_TRANSACTION_ERROR(cls):
        return cls("bank_transaction_error")
    
    @schemas.classproperty
    def FIAT_ACCOUNT_LIMIT_EXCEEDED(cls):
        return cls("fiat_account_limit_exceeded")
    
    @schemas.classproperty
    def INVALID_BANK_ACCOUNT_NUMBER(cls):
        return cls("invalid_bank_account_number")
    
    @schemas.classproperty
    def INVALID_ACH_RTN(cls):
        return cls("invalid_ach_rtn")
    
    @schemas.classproperty
    def INVALID_WIRE_RTN(cls):
        return cls("invalid_wire_rtn")
    
    @schemas.classproperty
    def VENDOR_INACTIVE(cls):
        return cls("vendor_inactive")


    def __new__(
        cls,
        *_args: typing.Union[None, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'PayoutErrorCode':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
        )



import circle
from circle.apis.tags.health_api import HealthApi

import unittest


class TestPing(unittest.TestCase):

    def setUp(self):
        circle.base_url = circle.Environment.SANDBOX_BASE_URL
        self.api = HealthApi()

    def test_ping(self):
        resp = self.api.ping()
        self.assertEquals(resp.body['message'], 'pong')


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CardCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "expMonth",
            "metadata",
            "billingDetails",
            "expYear",
            "idempotencyKey",
            "encryptedData",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
            encryptedData = schemas.StrSchema
        
            @staticmethod
            def billingDetails() -> typing.Type['BillingDetails']:
                return BillingDetails
        
            @staticmethod
            def expMonth() -> typing.Type['CardExpMonth']:
                return CardExpMonth
        
            @staticmethod
            def expYear() -> typing.Type['CardExpYear']:
                return CardExpYear
        
            @staticmethod
            def metadata() -> typing.Type['MetadataCardAndAch']:
                return MetadataCardAndAch
            keyId = schemas.UUIDSchema
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "encryptedData": encryptedData,
                "billingDetails": billingDetails,
                "expMonth": expMonth,
                "expYear": expYear,
                "metadata": metadata,
                "keyId": keyId,
            }
    
    expMonth: 'CardExpMonth'
    metadata: 'MetadataCardAndAch'
    billingDetails: 'BillingDetails'
    expYear: 'CardExpYear'
    idempotencyKey: MetaOapg.properties.idempotencyKey
    encryptedData: MetaOapg.properties.encryptedData
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["encryptedData"]) -> MetaOapg.properties.encryptedData: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataCardAndAch': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["keyId"]) -> MetaOapg.properties.keyId: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "encryptedData", "billingDetails", "expMonth", "expYear", "metadata", "keyId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["encryptedData"]) -> MetaOapg.properties.encryptedData: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["billingDetails"]) -> 'BillingDetails': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expMonth"]) -> 'CardExpMonth': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expYear"]) -> 'CardExpYear': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> 'MetadataCardAndAch': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["keyId"]) -> typing.Union[MetaOapg.properties.keyId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "encryptedData", "billingDetails", "expMonth", "expYear", "metadata", "keyId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        expMonth: 'CardExpMonth',
        metadata: 'MetadataCardAndAch',
        billingDetails: 'BillingDetails',
        expYear: 'CardExpYear',
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        encryptedData: typing.Union[MetaOapg.properties.encryptedData, str, ],
        keyId: typing.Union[MetaOapg.properties.keyId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CardCreationRequest':
        return super().__new__(
            cls,
            *_args,
            expMonth=expMonth,
            metadata=metadata,
            billingDetails=billingDetails,
            expYear=expYear,
            idempotencyKey=idempotencyKey,
            encryptedData=encryptedData,
            keyId=keyId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.billing_details import BillingDetails
from circle.model.card_exp_month import CardExpMonth
from circle.model.card_exp_year import CardExpYear
from circle.model.metadata_card_and_ach import MetadataCardAndAch



from circle.paths.v1_notifications_subscriptions.get import ApiForget
from circle.paths.v1_notifications_subscriptions.post import ApiForpost


class V1NotificationsSubscriptions(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Rate(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "buy",
            "sell",
            "createDate",
        }
        
        class properties:
            buy = schemas.StrSchema
            sell = schemas.StrSchema
            createDate = schemas.StrSchema
            __annotations__ = {
                "buy": buy,
                "sell": sell,
                "createDate": createDate,
            }
    
    buy: MetaOapg.properties.buy
    sell: MetaOapg.properties.sell
    createDate: MetaOapg.properties.createDate
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["buy"]) -> MetaOapg.properties.buy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sell"]) -> MetaOapg.properties.sell: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["buy", "sell", "createDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["buy"]) -> MetaOapg.properties.buy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sell"]) -> MetaOapg.properties.sell: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["buy", "sell", "createDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        buy: typing.Union[MetaOapg.properties.buy, str, ],
        sell: typing.Union[MetaOapg.properties.sell, str, ],
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Rate':
        return super().__new__(
            cls,
            *_args,
            buy=buy,
            sell=sell,
            createDate=createDate,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_wallets.post import CreateWallet
from circle.paths.v1_wallets_wallet_id_addresses.post import GenerateAddress
from circle.paths.v1_wallets_wallet_id.get import GetWallet
from circle.paths.v1_wallets_wallet_id_addresses.get import ListAddresses
from circle.paths.v1_wallets.get import ListWallets


class WalletsApi(
    CreateWallet,
    GenerateAddress,
    GetWallet,
    ListAddresses,
    ListWallets,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PresignResponseTypedData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The typed data
    """


    class MetaOapg:
        required = {
            "totalAmount",
            "types",
            "primaryType",
            "domain",
            "feeChargeModel",
            "message",
        }
        
        class properties:
        
            @staticmethod
            def domain() -> typing.Type['PresignDomain']:
                return PresignDomain
        
            @staticmethod
            def message() -> typing.Type['PresignMessage']:
                return PresignMessage
        
            @staticmethod
            def totalAmount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            
            
            class feeChargeModel(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "endUser": "END_USER",
                        "merchant": "MERCHANT",
                    }
                
                @schemas.classproperty
                def END_USER(cls):
                    return cls("endUser")
                
                @schemas.classproperty
                def MERCHANT(cls):
                    return cls("merchant")
        
            @staticmethod
            def types() -> typing.Type['PresignMessageTypes']:
                return PresignMessageTypes
            
            
            class primaryType(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "TransferWithAuthorization": "TRANSFER_WITH_AUTHORIZATION",
                        "EIP712Domain": "EIP712DOMAIN",
                    }
                
                @schemas.classproperty
                def TRANSFER_WITH_AUTHORIZATION(cls):
                    return cls("TransferWithAuthorization")
                
                @schemas.classproperty
                def EIP712DOMAIN(cls):
                    return cls("EIP712Domain")
        
            @staticmethod
            def networkFeeQuote() -> typing.Type['NetworkFeeQuote']:
                return NetworkFeeQuote
            __annotations__ = {
                "domain": domain,
                "message": message,
                "totalAmount": totalAmount,
                "feeChargeModel": feeChargeModel,
                "types": types,
                "primaryType": primaryType,
                "networkFeeQuote": networkFeeQuote,
            }
    
    totalAmount: 'FiatMoneyUsd'
    types: 'PresignMessageTypes'
    primaryType: MetaOapg.properties.primaryType
    domain: 'PresignDomain'
    feeChargeModel: MetaOapg.properties.feeChargeModel
    message: 'PresignMessage'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domain"]) -> 'PresignDomain': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["message"]) -> 'PresignMessage': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["feeChargeModel"]) -> MetaOapg.properties.feeChargeModel: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["types"]) -> 'PresignMessageTypes': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["primaryType"]) -> MetaOapg.properties.primaryType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["networkFeeQuote"]) -> 'NetworkFeeQuote': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["domain", "message", "totalAmount", "feeChargeModel", "types", "primaryType", "networkFeeQuote", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domain"]) -> 'PresignDomain': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["message"]) -> 'PresignMessage': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["feeChargeModel"]) -> MetaOapg.properties.feeChargeModel: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["types"]) -> 'PresignMessageTypes': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["primaryType"]) -> MetaOapg.properties.primaryType: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["networkFeeQuote"]) -> typing.Union['NetworkFeeQuote', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["domain", "message", "totalAmount", "feeChargeModel", "types", "primaryType", "networkFeeQuote", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        totalAmount: 'FiatMoneyUsd',
        types: 'PresignMessageTypes',
        primaryType: typing.Union[MetaOapg.properties.primaryType, str, ],
        domain: 'PresignDomain',
        feeChargeModel: typing.Union[MetaOapg.properties.feeChargeModel, str, ],
        message: 'PresignMessage',
        networkFeeQuote: typing.Union['NetworkFeeQuote', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PresignResponseTypedData':
        return super().__new__(
            cls,
            *_args,
            totalAmount=totalAmount,
            types=types,
            primaryType=primaryType,
            domain=domain,
            feeChargeModel=feeChargeModel,
            message=message,
            networkFeeQuote=networkFeeQuote,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.network_fee_quote import NetworkFeeQuote
from circle.model.presign_domain import PresignDomain
from circle.model.presign_message import PresignMessage
from circle.model.presign_message_types import PresignMessageTypes



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class ChargebackCategories(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated category of the chargeback status codes based on the chargeback status code.
    """
    
    @schemas.classproperty
    def CANCELED_RECURRING_PAYMENT(cls):
        return cls("Canceled Recurring Payment")
    
    @schemas.classproperty
    def CUSTOMER_DISPUTE(cls):
        return cls("Customer Dispute")
    
    @schemas.classproperty
    def FRAUDULENT(cls):
        return cls("Fraudulent")
    
    @schemas.classproperty
    def GENERAL(cls):
        return cls("General")
    
    @schemas.classproperty
    def PROCESSING_ERROR(cls):
        return cls("Processing Error")
    
    @schemas.classproperty
    def NOT_DEFINED(cls):
        return cls("Not Defined")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CryptoPayout(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            id = schemas.UUIDSchema
            sourceWalletId = schemas.StrSchema
        
            @staticmethod
            def destination() -> typing.Type['CryptoPayoutDestination']:
                return CryptoPayoutDestination
        
            @staticmethod
            def amount() -> typing.Type['PayoutMoney']:
                return PayoutMoney
        
            @staticmethod
            def toAmount() -> typing.Type['PayoutMoney']:
                return PayoutMoney
        
            @staticmethod
            def fees() -> typing.Type['PayoutMoney']:
                return PayoutMoney
        
            @staticmethod
            def networkFees() -> typing.Type['PayoutMoney']:
                return PayoutMoney
        
            @staticmethod
            def status() -> typing.Type['PayoutStatus']:
                return PayoutStatus
        
            @staticmethod
            def errorCode() -> typing.Type['PayoutErrorCode']:
                return PayoutErrorCode
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "sourceWalletId": sourceWalletId,
                "destination": destination,
                "amount": amount,
                "toAmount": toAmount,
                "fees": fees,
                "networkFees": networkFees,
                "status": status,
                "errorCode": errorCode,
                "riskEvaluation": riskEvaluation,
                "createDate": createDate,
                "updateDate": updateDate,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sourceWalletId"]) -> MetaOapg.properties.sourceWalletId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination"]) -> 'CryptoPayoutDestination': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'PayoutMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["toAmount"]) -> 'PayoutMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fees"]) -> 'PayoutMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["networkFees"]) -> 'PayoutMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'PayoutStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["errorCode"]) -> 'PayoutErrorCode': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "sourceWalletId", "destination", "amount", "toAmount", "fees", "networkFees", "status", "errorCode", "riskEvaluation", "createDate", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sourceWalletId"]) -> typing.Union[MetaOapg.properties.sourceWalletId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination"]) -> typing.Union['CryptoPayoutDestination', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> typing.Union['PayoutMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["toAmount"]) -> typing.Union['PayoutMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fees"]) -> typing.Union['PayoutMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["networkFees"]) -> typing.Union['PayoutMoney', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union['PayoutStatus', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["errorCode"]) -> typing.Union['PayoutErrorCode', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "sourceWalletId", "destination", "amount", "toAmount", "fees", "networkFees", "status", "errorCode", "riskEvaluation", "createDate", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, schemas.Unset] = schemas.unset,
        sourceWalletId: typing.Union[MetaOapg.properties.sourceWalletId, str, schemas.Unset] = schemas.unset,
        destination: typing.Union['CryptoPayoutDestination', schemas.Unset] = schemas.unset,
        amount: typing.Union['PayoutMoney', schemas.Unset] = schemas.unset,
        toAmount: typing.Union['PayoutMoney', schemas.Unset] = schemas.unset,
        fees: typing.Union['PayoutMoney', schemas.Unset] = schemas.unset,
        networkFees: typing.Union['PayoutMoney', schemas.Unset] = schemas.unset,
        status: typing.Union['PayoutStatus', schemas.Unset] = schemas.unset,
        errorCode: typing.Union['PayoutErrorCode', schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CryptoPayout':
        return super().__new__(
            cls,
            *_args,
            id=id,
            sourceWalletId=sourceWalletId,
            destination=destination,
            amount=amount,
            toAmount=toAmount,
            fees=fees,
            networkFees=networkFees,
            status=status,
            errorCode=errorCode,
            riskEvaluation=riskEvaluation,
            createDate=createDate,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payout_destination import CryptoPayoutDestination
from circle.model.payout_error_code import PayoutErrorCode
from circle.model.payout_money import PayoutMoney
from circle.model.payout_status import PayoutStatus
from circle.model.risk_evaluation import RiskEvaluation



from circle.paths.v1_address_book_recipients.get import ApiForget
from circle.paths.v1_address_book_recipients.post import ApiForpost


class V1AddressBookRecipients(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class Eci(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    ECI (electronic commerce indicator) value returned by Directory Servers (namely Visa, MasterCard, JCB, and American Express) indicating the outcome of authentication attempted on transactions enforced by 3DS.
    """


    class MetaOapg:
        enum_value_to_name = {
            "00": "POSITIVE_00",
            "01": "POSITIVE_01",
            "02": "POSITIVE_02",
            "05": "POSITIVE_05",
            "06": "POSITIVE_06",
            "07": "POSITIVE_07",
        }
    
    @schemas.classproperty
    def POSITIVE_00(cls):
        return cls("00")
    
    @schemas.classproperty
    def POSITIVE_01(cls):
        return cls("01")
    
    @schemas.classproperty
    def POSITIVE_02(cls):
        return cls("02")
    
    @schemas.classproperty
    def POSITIVE_05(cls):
        return cls("05")
    
    @schemas.classproperty
    def POSITIVE_06(cls):
        return cls("06")
    
    @schemas.classproperty
    def POSITIVE_07(cls):
        return cls("07")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class CheckoutSession(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "paymentIds",
            "amount",
            "updateDate",
            "amountPaid",
            "clientToken",
            "expiresOn",
            "id",
            "type",
            "createDate",
            "paymentIntentIds",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "checkout_session": "CHECKOUT_SESSION",
                    }
                
                @schemas.classproperty
                def CHECKOUT_SESSION(cls):
                    return cls("checkout_session")
            clientToken = schemas.StrSchema
        
            @staticmethod
            def status() -> typing.Type['CheckoutSessionStatus']:
                return CheckoutSessionStatus
            expiresOn = schemas.StrSchema
            createDate = schemas.StrSchema
            updateDate = schemas.StrSchema
        
            @staticmethod
            def amount() -> typing.Type['CheckoutSessionMoney']:
                return CheckoutSessionMoney
        
            @staticmethod
            def amountPaid() -> typing.Type['CheckoutSessionMoney']:
                return CheckoutSessionMoney
            
            
            class paymentIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.UUIDSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentIds':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            
            
            class paymentIntentIds(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.UUIDSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, uuid.UUID, ]], typing.List[typing.Union[MetaOapg.items, str, uuid.UUID, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentIntentIds':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            successUrl = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "type": type,
                "clientToken": clientToken,
                "status": status,
                "expiresOn": expiresOn,
                "createDate": createDate,
                "updateDate": updateDate,
                "amount": amount,
                "amountPaid": amountPaid,
                "paymentIds": paymentIds,
                "paymentIntentIds": paymentIntentIds,
                "successUrl": successUrl,
            }
    
    paymentIds: MetaOapg.properties.paymentIds
    amount: 'CheckoutSessionMoney'
    updateDate: MetaOapg.properties.updateDate
    amountPaid: 'CheckoutSessionMoney'
    clientToken: MetaOapg.properties.clientToken
    expiresOn: MetaOapg.properties.expiresOn
    id: MetaOapg.properties.id
    type: MetaOapg.properties.type
    createDate: MetaOapg.properties.createDate
    paymentIntentIds: MetaOapg.properties.paymentIntentIds
    status: 'CheckoutSessionStatus'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["clientToken"]) -> MetaOapg.properties.clientToken: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> 'CheckoutSessionStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expiresOn"]) -> MetaOapg.properties.expiresOn: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'CheckoutSessionMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amountPaid"]) -> 'CheckoutSessionMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentIds"]) -> MetaOapg.properties.paymentIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentIntentIds"]) -> MetaOapg.properties.paymentIntentIds: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["successUrl"]) -> MetaOapg.properties.successUrl: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "type", "clientToken", "status", "expiresOn", "createDate", "updateDate", "amount", "amountPaid", "paymentIds", "paymentIntentIds", "successUrl", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["clientToken"]) -> MetaOapg.properties.clientToken: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> 'CheckoutSessionStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expiresOn"]) -> MetaOapg.properties.expiresOn: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'CheckoutSessionMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amountPaid"]) -> 'CheckoutSessionMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentIds"]) -> MetaOapg.properties.paymentIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentIntentIds"]) -> MetaOapg.properties.paymentIntentIds: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["successUrl"]) -> typing.Union[MetaOapg.properties.successUrl, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "type", "clientToken", "status", "expiresOn", "createDate", "updateDate", "amount", "amountPaid", "paymentIds", "paymentIntentIds", "successUrl", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        paymentIds: typing.Union[MetaOapg.properties.paymentIds, list, tuple, ],
        amount: 'CheckoutSessionMoney',
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, ],
        amountPaid: 'CheckoutSessionMoney',
        clientToken: typing.Union[MetaOapg.properties.clientToken, str, ],
        expiresOn: typing.Union[MetaOapg.properties.expiresOn, str, ],
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        paymentIntentIds: typing.Union[MetaOapg.properties.paymentIntentIds, list, tuple, ],
        status: 'CheckoutSessionStatus',
        successUrl: typing.Union[MetaOapg.properties.successUrl, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'CheckoutSession':
        return super().__new__(
            cls,
            *_args,
            paymentIds=paymentIds,
            amount=amount,
            updateDate=updateDate,
            amountPaid=amountPaid,
            clientToken=clientToken,
            expiresOn=expiresOn,
            id=id,
            type=type,
            createDate=createDate,
            paymentIntentIds=paymentIntentIds,
            status=status,
            successUrl=successUrl,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.checkout_session_money import CheckoutSessionMoney
from circle.model.checkout_session_status import CheckoutSessionStatus



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class WireCreationRequest(
    schemas.ComposedBase,
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Request object used to create a bank account (wires). Different fields are required depending on the bank country, see the guide documentation for the list of supported bank countries along with which ones support IBAN.
    """


    class MetaOapg:
        
        @classmethod
        @functools.lru_cache()
        def one_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                WireCreationRequestUs,
                WireCreationRequestIban,
                WireCreationRequestAccountNumber,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'WireCreationRequest':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.wire_creation_request_account_number import WireCreationRequestAccountNumber
from circle.model.wire_creation_request_iban import WireCreationRequestIban
from circle.model.wire_creation_request_us import WireCreationRequestUs



from circle.paths.v1_business_account_banks_wires.get import ApiForget
from circle.paths.v1_business_account_banks_wires.post import ApiForpost


class V1BusinessAccountBanksWires(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BusinessDeposit(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    A deposit
    """


    class MetaOapg:
        required = {
            "amount",
            "destination",
            "id",
            "createDate",
            "status",
        }
        
        class properties:
            id = schemas.UUIDSchema
        
            @staticmethod
            def destination() -> typing.Type['WalletLocation']:
                return WalletLocation
        
            @staticmethod
            def amount() -> typing.Type['FiatMoney']:
                return FiatMoney
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def PENDING(cls):
                    return cls("pending")
                
                @schemas.classproperty
                def COMPLETE(cls):
                    return cls("complete")
                
                @schemas.classproperty
                def FAILED(cls):
                    return cls("failed")
            createDate = schemas.StrSchema
            sourceWalletId = schemas.UUIDSchema
        
            @staticmethod
            def fee() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def riskEvaluation() -> typing.Type['RiskEvaluation']:
                return RiskEvaluation
            updateDate = schemas.StrSchema
            __annotations__ = {
                "id": id,
                "destination": destination,
                "amount": amount,
                "status": status,
                "createDate": createDate,
                "sourceWalletId": sourceWalletId,
                "fee": fee,
                "riskEvaluation": riskEvaluation,
                "updateDate": updateDate,
            }
    
    amount: 'FiatMoney'
    destination: 'WalletLocation'
    id: MetaOapg.properties.id
    createDate: MetaOapg.properties.createDate
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["destination"]) -> 'WalletLocation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sourceWalletId"]) -> MetaOapg.properties.sourceWalletId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fee"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["riskEvaluation"]) -> 'RiskEvaluation': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updateDate"]) -> MetaOapg.properties.updateDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "destination", "amount", "status", "createDate", "sourceWalletId", "fee", "riskEvaluation", "updateDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["destination"]) -> 'WalletLocation': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'FiatMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sourceWalletId"]) -> typing.Union[MetaOapg.properties.sourceWalletId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fee"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["riskEvaluation"]) -> typing.Union['RiskEvaluation', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updateDate"]) -> typing.Union[MetaOapg.properties.updateDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "destination", "amount", "status", "createDate", "sourceWalletId", "fee", "riskEvaluation", "updateDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'FiatMoney',
        destination: 'WalletLocation',
        id: typing.Union[MetaOapg.properties.id, str, uuid.UUID, ],
        createDate: typing.Union[MetaOapg.properties.createDate, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        sourceWalletId: typing.Union[MetaOapg.properties.sourceWalletId, str, uuid.UUID, schemas.Unset] = schemas.unset,
        fee: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        riskEvaluation: typing.Union['RiskEvaluation', schemas.Unset] = schemas.unset,
        updateDate: typing.Union[MetaOapg.properties.updateDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BusinessDeposit':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            destination=destination,
            id=id,
            createDate=createDate,
            status=status,
            sourceWalletId=sourceWalletId,
            fee=fee,
            riskEvaluation=riskEvaluation,
            updateDate=updateDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money import FiatMoney
from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.risk_evaluation import RiskEvaluation
from circle.model.wallet_location import WalletLocation



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentStatus(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Enumerated status of the payment. `pending` means the payment is waiting to be processed. `confirmed` means the payment has been approved by the bank and the merchant can treat it as successful, but settlement funds are not yet available to the merchant.  `paid` means settlement funds have been received and are available to the merchant. `failed` means something went wrong (most commonly that the payment was denied). `action_required` means that additional steps are required to process this payment; refer to `requiredAction` for more details. Terminal states are `paid` and `failed`.
    """


    class MetaOapg:
        enum_value_to_name = {
            "pending": "PENDING",
            "confirmed": "CONFIRMED",
            "paid": "PAID",
            "failed": "FAILED",
            "action_required": "ACTION_REQUIRED",
        }
    
    @schemas.classproperty
    def PENDING(cls):
        return cls("pending")
    
    @schemas.classproperty
    def CONFIRMED(cls):
        return cls("confirmed")
    
    @schemas.classproperty
    def PAID(cls):
        return cls("paid")
    
    @schemas.classproperty
    def FAILED(cls):
        return cls("failed")
    
    @schemas.classproperty
    def ACTION_REQUIRED(cls):
        return cls("action_required")



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from circle import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401

from circle.model.not_authorized import NotAuthorized
from circle.model.wire_creation_request import WireCreationRequest
from circle.model.bad_request import BadRequest
from circle.model.create_business_wire_account_response import CreateBusinessWireAccountResponse

from . import path

# body param
SchemaForRequestBodyApplicationJson = WireCreationRequest


request_body_wire_creation_request = api_client.RequestBody(
    content={
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
)
_auth = [
    'bearerAuth',
]
XRequestIdSchema = schemas.UUIDSchema
x_request_id_parameter = api_client.HeaderParameter(
    name="X-Request-Id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=XRequestIdSchema,
)
SchemaFor201ResponseBodyApplicationJson = CreateBusinessWireAccountResponse
ResponseHeadersFor201 = typing_extensions.TypedDict(
    'ResponseHeadersFor201',
    {
        'X-Request-Id': XRequestIdSchema,
    }
)


@dataclass
class ApiResponseFor201(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor201ResponseBodyApplicationJson,
    ]
    headers: ResponseHeadersFor201


_response_for_201 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor201,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor201ResponseBodyApplicationJson),
    },
    headers=[
        x_request_id_parameter,
    ]
)
XRequestIdSchema = schemas.UUIDSchema
x_request_id_parameter = api_client.HeaderParameter(
    name="X-Request-Id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=XRequestIdSchema,
)
SchemaFor400ResponseBodyApplicationJson = BadRequest
ResponseHeadersFor400 = typing_extensions.TypedDict(
    'ResponseHeadersFor400',
    {
        'X-Request-Id': XRequestIdSchema,
    }
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: ResponseHeadersFor400


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
    headers=[
        x_request_id_parameter,
    ]
)
XRequestIdSchema = schemas.UUIDSchema
x_request_id_parameter = api_client.HeaderParameter(
    name="X-Request-Id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=XRequestIdSchema,
)
SchemaFor401ResponseBodyApplicationJson = NotAuthorized
ResponseHeadersFor401 = typing_extensions.TypedDict(
    'ResponseHeadersFor401',
    {
        'X-Request-Id': XRequestIdSchema,
    }
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: ResponseHeadersFor401


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
    headers=[
        x_request_id_parameter,
    ]
)
_status_code_to_response = {
    '201': _response_for_201,
    '400': _response_for_400,
    '401': _response_for_401,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _create_business_wire_account_oapg(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...

    @typing.overload
    def _create_business_wire_account_oapg(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...


    @typing.overload
    def _create_business_wire_account_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _create_business_wire_account_oapg(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _create_business_wire_account_oapg(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Create a Wire bank account
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        used_path = path.value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        _fields = None
        _body = None
        if body is not schemas.unset:
            serialized_data = request_body_wire_creation_request.serialize(body, content_type)
            _headers.add('Content-Type', content_type)
            if 'fields' in serialized_data:
                _fields = serialized_data['fields']
            elif 'body' in serialized_data:
                _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class CreateBusinessWireAccount(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def create_business_wire_account(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...

    @typing.overload
    def create_business_wire_account(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...


    @typing.overload
    def create_business_wire_account(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def create_business_wire_account(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def create_business_wire_account(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._create_business_wire_account_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def post(
        self,
        content_type: typing_extensions.Literal["application/json"] = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...

    @typing.overload
    def post(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor201,
    ]: ...


    @typing.overload
    def post(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def post(
        self,
        content_type: str = ...,
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor201,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def post(
        self,
        content_type: str = 'application/json',
        body: typing.Union[SchemaForRequestBodyApplicationJson, schemas.Unset] = schemas.unset,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._create_business_wire_account_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_payouts.post import CreateBusinessPayout
from circle.paths.v1_payouts.post import CreatePayout
from circle.paths.v1_business_account_payouts_id.get import GetBusinessPayout
from circle.paths.v1_payouts_id.get import GetPayout
from circle.paths.v1_business_account_payouts.get import ListBusinessPayouts
from circle.paths.v1_payouts.get import ListPayouts


class PayoutsApi(
    CreateBusinessPayout,
    CreatePayout,
    GetBusinessPayout,
    GetPayout,
    ListBusinessPayouts,
    ListPayouts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from circle.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    PING = "/ping"
    V1_CONFIGURATION = "/v1/configuration"
    V1_ENCRYPTION_PUBLIC = "/v1/encryption/public"
    V1_NOTIFICATIONS_SUBSCRIPTIONS = "/v1/notifications/subscriptions"
    V1_NOTIFICATIONS_SUBSCRIPTIONS_ID = "/v1/notifications/subscriptions/{id}"
    V1_CHANNELS = "/v1/channels"
    V1_STABLECOINS = "/v1/stablecoins"
    V1_BUSINESS_ACCOUNT_BALANCES = "/v1/businessAccount/balances"
    V1_BALANCES = "/v1/balances"
    V1_CARDS = "/v1/cards"
    V1_CARDS_ID = "/v1/cards/{id}"
    V1_PAYMENT_TOKENS = "/v1/paymentTokens"
    V1_BUSINESS_ACCOUNT_BANKS_WIRES = "/v1/businessAccount/banks/wires"
    V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID = "/v1/businessAccount/banks/wires/{id}"
    V1_BUSINESS_ACCOUNT_BANKS_WIRES_ID_INSTRUCTIONS = "/v1/businessAccount/banks/wires/{id}/instructions"
    V1_BUSINESS_ACCOUNT_BANKS_CBIT = "/v1/businessAccount/banks/cbit"
    V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID = "/v1/businessAccount/banks/cbit/{id}"
    V1_BUSINESS_ACCOUNT_BANKS_CBIT_ID_INSTRUCTIONS = "/v1/businessAccount/banks/cbit/{id}/instructions"
    V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_DEPOSIT = "/v1/businessAccount/wallets/addresses/deposit"
    V1_BUSINESS_ACCOUNT_WALLETS_ADDRESSES_RECIPIENT = "/v1/businessAccount/wallets/addresses/recipient"
    V1_BUSINESS_ACCOUNT_DEPOSITS = "/v1/businessAccount/deposits"
    V1_PAYMENT_INTENTS = "/v1/paymentIntents"
    V1_PAYMENT_INTENTS_ID = "/v1/paymentIntents/{id}"
    V1_PAYMENT_INTENTS_ID_EXPIRE = "/v1/paymentIntents/{id}/expire"
    V1_PAYMENT_INTENTS_ID_REFUND = "/v1/paymentIntents/{id}/refund"
    V1_ADDRESS_BOOK_RECIPIENTS = "/v1/addressBook/recipients"
    V1_ADDRESS_BOOK_RECIPIENTS_ID = "/v1/addressBook/recipients/{id}"
    V1_PAYMENTS = "/v1/payments"
    V1_PAYMENTS_CRYPTO = "/v1/payments/crypto"
    V1_PAYMENTS_ID = "/v1/payments/{id}"
    V1_PAYMENTS_ID_CAPTURE = "/v1/payments/{id}/capture"
    V1_PAYMENTS_ID_CANCEL = "/v1/payments/{id}/cancel"
    V1_PAYMENTS_ID_REFUND = "/v1/payments/{id}/refund"
    V1_PAYMENTS_PRESIGN = "/v1/payments/presign"
    V1_BUSINESS_ACCOUNT_PAYOUTS = "/v1/businessAccount/payouts"
    V1_BUSINESS_ACCOUNT_PAYOUTS_ID = "/v1/businessAccount/payouts/{id}"
    V1_PAYOUTS = "/v1/payouts"
    V1_PAYOUTS_ID = "/v1/payouts/{id}"
    V1_EXCHANGE_RATES_TRADINGPAIR = "/v1/exchange/rates/{trading-pair}"
    V1_SETTLEMENTS = "/v1/settlements"
    V1_SETTLEMENTS_ID = "/v1/settlements/{id}"
    V1_CHARGEBACKS = "/v1/chargebacks"
    V1_CHARGEBACKS_ID = "/v1/chargebacks/{id}"
    V1_WALLETS = "/v1/wallets"
    V1_WALLETS_WALLET_ID = "/v1/wallets/{walletId}"
    V1_WALLETS_WALLET_ID_ADDRESSES = "/v1/wallets/{walletId}/addresses"
    V1_BUSINESS_ACCOUNT_TRANSFERS = "/v1/businessAccount/transfers"
    V1_BUSINESS_ACCOUNT_TRANSFERS_ID = "/v1/businessAccount/transfers/{id}"
    V1_TRANSFERS = "/v1/transfers"
    V1_TRANSFERS_ID = "/v1/transfers/{id}"
    V1_MOCKS_CARDS_CHARGEBACKS = "/v1/mocks/cards/chargebacks"
    V1_MOCKS_PAYMENTS_WIRE = "/v1/mocks/payments/wire"
    V1_CHECKOUT_SESSIONS = "/v1/checkoutSessions"
    V1_CHECKOUT_SESSIONS_ID = "/v1/checkoutSessions/{id}"
    V1_CHECKOUT_SESSIONS_ID_EXTEND = "/v1/checkoutSessions/{id}/extend"



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_business_account_banks_wires.post import CreateBusinessWireAccount
from circle.paths.v1_business_account_banks_wires_id.get import GetBusinessWireAccount
from circle.paths.v1_business_account_banks_wires_id_instructions.get import GetBusinessWireAccountInstructions
from circle.paths.v1_business_account_banks_wires.get import ListBusinessWireAccounts


class WiresApi(
    CreateBusinessWireAccount,
    GetBusinessWireAccount,
    GetBusinessWireAccountInstructions,
    ListBusinessWireAccounts,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BankAddress(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The address details for the bank, as provided during bank account creation.
    """


    class MetaOapg:
        required = {
            "country",
        }
        
        class properties:
            
            
            class country(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 2
            
            
            class bankName(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 35
            
            
            class city(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 35
            
            
            class line1(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 35
            
            
            class line2(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 35
            
            
            class district(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 16
            __annotations__ = {
                "country": country,
                "bankName": bankName,
                "city": city,
                "line1": line1,
                "line2": line2,
                "district": district,
            }
    
    country: MetaOapg.properties.country
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["country"]) -> MetaOapg.properties.country: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["bankName"]) -> MetaOapg.properties.bankName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["city"]) -> MetaOapg.properties.city: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["line1"]) -> MetaOapg.properties.line1: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["line2"]) -> MetaOapg.properties.line2: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["district"]) -> MetaOapg.properties.district: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["country", "bankName", "city", "line1", "line2", "district", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["country"]) -> MetaOapg.properties.country: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["bankName"]) -> typing.Union[MetaOapg.properties.bankName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["city"]) -> typing.Union[MetaOapg.properties.city, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["line1"]) -> typing.Union[MetaOapg.properties.line1, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["line2"]) -> typing.Union[MetaOapg.properties.line2, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["district"]) -> typing.Union[MetaOapg.properties.district, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["country", "bankName", "city", "line1", "line2", "district", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        country: typing.Union[MetaOapg.properties.country, str, ],
        bankName: typing.Union[MetaOapg.properties.bankName, str, schemas.Unset] = schemas.unset,
        city: typing.Union[MetaOapg.properties.city, str, schemas.Unset] = schemas.unset,
        line1: typing.Union[MetaOapg.properties.line1, str, schemas.Unset] = schemas.unset,
        line2: typing.Union[MetaOapg.properties.line2, str, schemas.Unset] = schemas.unset,
        district: typing.Union[MetaOapg.properties.district, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BankAddress':
        return super().__new__(
            cls,
            *_args,
            country=country,
            bankName=bankName,
            city=city,
            line1=line1,
            line2=line2,
            district=district,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class BasicChargebackHistory(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "description",
            "type",
            "chargebackAmount",
        }
        
        class properties:
            
            
            class type(
                schemas.EnumBase,
                schemas.StrSchema
            ):
                
                @schemas.classproperty
                def ST_CHARGEBACK(cls):
                    return cls("1st Chargeback")
                
                @schemas.classproperty
                def ND_CHARGEBACK(cls):
                    return cls("2nd Chargeback")
                
                @schemas.classproperty
                def CHARGEBACK_REVERSAL(cls):
                    return cls("Chargeback Reversal")
                
                @schemas.classproperty
                def REPRESENTMENT(cls):
                    return cls("Representment")
                
                @schemas.classproperty
                def CHARGEBACK_SETTLEMENT(cls):
                    return cls("Chargeback Settlement")
        
            @staticmethod
            def chargebackAmount() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
            description = schemas.StrSchema
        
            @staticmethod
            def fee() -> typing.Type['FiatMoneyUsd']:
                return FiatMoneyUsd
        
            @staticmethod
            def settlementId() -> typing.Type['IdSettlement']:
                return IdSettlement
            createDate = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "chargebackAmount": chargebackAmount,
                "description": description,
                "fee": fee,
                "settlementId": settlementId,
                "createDate": createDate,
            }
    
    description: MetaOapg.properties.description
    type: MetaOapg.properties.type
    chargebackAmount: 'FiatMoneyUsd'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["chargebackAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["fee"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementId"]) -> 'IdSettlement': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createDate"]) -> MetaOapg.properties.createDate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "chargebackAmount", "description", "fee", "settlementId", "createDate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["chargebackAmount"]) -> 'FiatMoneyUsd': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["fee"]) -> typing.Union['FiatMoneyUsd', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementId"]) -> typing.Union['IdSettlement', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createDate"]) -> typing.Union[MetaOapg.properties.createDate, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "chargebackAmount", "description", "fee", "settlementId", "createDate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        chargebackAmount: 'FiatMoneyUsd',
        fee: typing.Union['FiatMoneyUsd', schemas.Unset] = schemas.unset,
        settlementId: typing.Union['IdSettlement', schemas.Unset] = schemas.unset,
        createDate: typing.Union[MetaOapg.properties.createDate, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BasicChargebackHistory':
        return super().__new__(
            cls,
            *_args,
            description=description,
            type=type,
            chargebackAmount=chargebackAmount,
            fee=fee,
            settlementId=settlementId,
            createDate=createDate,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.fiat_money_usd import FiatMoneyUsd
from circle.model.id_settlement import IdSettlement



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentIntentCreationRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "amount",
            "settlementCurrency",
            "idempotencyKey",
            "paymentMethods",
        }
        
        class properties:
            idempotencyKey = schemas.UUIDSchema
        
            @staticmethod
            def amount() -> typing.Type['CryptoPaymentsMoney']:
                return CryptoPaymentsMoney
            
            
            class settlementCurrency(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "USD": "USD",
                        "BTC": "BTC",
                        "ETH": "ETH",
                    }
                
                @schemas.classproperty
                def USD(cls):
                    return cls("USD")
                
                @schemas.classproperty
                def BTC(cls):
                    return cls("BTC")
                
                @schemas.classproperty
                def ETH(cls):
                    return cls("ETH")
            
            
            class paymentMethods(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['PaymentMethodBlockchain']:
                        return PaymentMethodBlockchain
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['PaymentMethodBlockchain'], typing.List['PaymentMethodBlockchain']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'paymentMethods':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'PaymentMethodBlockchain':
                    return super().__getitem__(i)
        
            @staticmethod
            def merchantWalletId() -> typing.Type['MerchantWalletId']:
                return MerchantWalletId
            __annotations__ = {
                "idempotencyKey": idempotencyKey,
                "amount": amount,
                "settlementCurrency": settlementCurrency,
                "paymentMethods": paymentMethods,
                "merchantWalletId": merchantWalletId,
            }
    
    amount: 'CryptoPaymentsMoney'
    settlementCurrency: MetaOapg.properties.settlementCurrency
    idempotencyKey: MetaOapg.properties.idempotencyKey
    paymentMethods: MetaOapg.properties.paymentMethods
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["merchantWalletId"]) -> 'MerchantWalletId': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "amount", "settlementCurrency", "paymentMethods", "merchantWalletId", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["idempotencyKey"]) -> MetaOapg.properties.idempotencyKey: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["amount"]) -> 'CryptoPaymentsMoney': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["settlementCurrency"]) -> MetaOapg.properties.settlementCurrency: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["paymentMethods"]) -> MetaOapg.properties.paymentMethods: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["merchantWalletId"]) -> typing.Union['MerchantWalletId', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["idempotencyKey", "amount", "settlementCurrency", "paymentMethods", "merchantWalletId", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        amount: 'CryptoPaymentsMoney',
        settlementCurrency: typing.Union[MetaOapg.properties.settlementCurrency, str, ],
        idempotencyKey: typing.Union[MetaOapg.properties.idempotencyKey, str, uuid.UUID, ],
        paymentMethods: typing.Union[MetaOapg.properties.paymentMethods, list, tuple, ],
        merchantWalletId: typing.Union['MerchantWalletId', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentIntentCreationRequest':
        return super().__new__(
            cls,
            *_args,
            amount=amount,
            settlementCurrency=settlementCurrency,
            idempotencyKey=idempotencyKey,
            paymentMethods=paymentMethods,
            merchantWalletId=merchantWalletId,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.crypto_payments_money import CryptoPaymentsMoney
from circle.model.merchant_wallet_id import MerchantWalletId
from circle.model.payment_method_blockchain import PaymentMethodBlockchain



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class PaymentVerificationResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Indicates the status of the payment verification. This property will be present once the payment is confirmed.
    """


    class MetaOapg:
        required = {
            "cvv",
            "avs",
        }
        
        class properties:
            avs = schemas.StrSchema
        
            @staticmethod
            def cvv() -> typing.Type['CvvResults']:
                return CvvResults
        
            @staticmethod
            def threeDSecure() -> typing.Type['ThreeDsResult']:
                return ThreeDsResult
        
            @staticmethod
            def eci() -> typing.Type['Eci']:
                return Eci
            __annotations__ = {
                "avs": avs,
                "cvv": cvv,
                "threeDSecure": threeDSecure,
                "eci": eci,
            }
    
    cvv: 'CvvResults'
    avs: MetaOapg.properties.avs
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["avs"]) -> MetaOapg.properties.avs: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cvv"]) -> 'CvvResults': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["threeDSecure"]) -> 'ThreeDsResult': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["eci"]) -> 'Eci': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["avs", "cvv", "threeDSecure", "eci", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["avs"]) -> MetaOapg.properties.avs: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cvv"]) -> 'CvvResults': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["threeDSecure"]) -> typing.Union['ThreeDsResult', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["eci"]) -> typing.Union['Eci', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["avs", "cvv", "threeDSecure", "eci", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        cvv: 'CvvResults',
        avs: typing.Union[MetaOapg.properties.avs, str, ],
        threeDSecure: typing.Union['ThreeDsResult', schemas.Unset] = schemas.unset,
        eci: typing.Union['Eci', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'PaymentVerificationResponse':
        return super().__new__(
            cls,
            *_args,
            cvv=cvv,
            avs=avs,
            threeDSecure=threeDSecure,
            eci=eci,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.cvv_results import CvvResults
from circle.model.eci import Eci
from circle.model.three_ds_result import ThreeDsResult



from circle.paths.v1_business_account_payouts.get import ApiForget
from circle.paths.v1_business_account_payouts.post import ApiForpost


class V1BusinessAccountPayouts(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from circle.paths.v1_cards.post import CreateCard
from circle.paths.v1_cards_id.get import GetCard
from circle.paths.v1_cards.get import ListCards
from circle.paths.v1_cards_id.put import UpdateCard


class CardsApi(
    CreateCard,
    GetCard,
    ListCards,
    UpdateCard,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from circle import schemas  # noqa: F401


class TransferCreationRequestDestination(
    schemas.ComposedSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        @classmethod
        @functools.lru_cache()
        def one_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                TransferRequestBlockchainLocation,
                WalletLocation,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TransferCreationRequestDestination':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from circle.model.transfer_request_blockchain_location import TransferRequestBlockchainLocation
from circle.model.wallet_location import WalletLocation
